@@ -26,5 +26,27 @@ def timeseries_write(
         pass
     else:
         metric.check_threshold(**check_threshold_kwargs)
-        signal_kwargs = dict(sender=metric.__class__, metric=metric, values=values)
+        signal_kwargs = dict(
+            sender=metric.__class__,
+            metric=metric,
+            values=values,
+            time=kwargs.get('timestamp'),
+            current=kwargs.get('current', 'False'),
+        )
         post_metric_write.send(**signal_kwargs)
+
+
+@shared_task
+def migrate_timeseries_database():
+    """
+    Perform migrations on timeseries database
+    asynchronously for changes introduced in
+    https://github.com/openwisp/openwisp-monitoring/pull/368
+
+    To be removed in 1.1.0 release.
+    """
+    from .migrations.influxdb.influxdb_alter_structure_0006 import (
+        migrate_influxdb_structure,
+    )
+
+    migrate_influxdb_structure()
